@@ -6,6 +6,8 @@
 
 #define MSG_500 ("HTTP/1.0 500 Internal Server Error\r\nContent-Type: text/html\r\nServer:  " SERVER "\r\n\r\n<html><head><title>500 Internal Server Error</head><h1>Internal Server Error</h1><p>The server encountered an internal error and was unable to complete your request.  Either the server is overloaded or there is an error in the application.</p></html>\n")
 
+#define MSG_503 ("HTTP/1.0 503 Service Unavailable\r\nContent-Type: text/html\r\nServer: " SERVER "\r\n\r\n<html><head><title>Service Unavailable</head><body><p>Service Unavailable.</p></body></html>")
+
 #define MSG_400 ("HTTP/1.0 400 Bad Request\r\nContent-Type: text/html\r\nServer: " SERVER "\r\n\r\n<html><head><title>Bad Request</head><body><p>Bad Request.</p></body></html>")
 
 #define MSG_411 ("HTTP/1.0 411 Length Required\r\nContent-Type: text/html\r\nServer: " SERVER "\r\n\r\n<html><head><title>Length Required</head><body><p>Length Required.</p></body></html>")
@@ -70,6 +72,9 @@ send_error_page(client_t *client)
         case 413:
             blocking_write(client, MSG_413, sizeof(MSG_413) -1);
             break;
+        case 503:
+            blocking_write(client, MSG_503, sizeof(MSG_503) -1);
+            break;
         default:
             //Internal Server Error
             blocking_write(client, MSG_500, sizeof(MSG_500) -1);
@@ -713,6 +718,17 @@ FileWrapperObject_new(PyObject *self, PyObject *filelike, size_t blksize)
     return (PyObject *)f;
 }
 
+static PyObject * 
+FileWrapperObject_iter(FileWrapperObject* self)
+{
+    PyObject *iterator = PyObject_GetIter(self->filelike);
+    if (iterator == NULL) {
+        PyErr_SetString(PyExc_TypeError, "file-like object must be a iterable object");
+        return NULL;
+    }
+    return (PyObject *)iterator;
+}
+
 static void
 FileWrapperObject_dealloc(FileWrapperObject* self)
 {
@@ -833,7 +849,7 @@ PyTypeObject FileWrapperType = {
     0,		               /* tp_clear */
     0,		               /* tp_richcompare */
     0,		               /* tp_weaklistoffset */
-    0,		               /* tp_iter */
+    FileWrapperObject_iter,		               /* tp_iter */
     0,		               /* tp_iternext */
     FileWrapperObject_method,             /* tp_methods */
     0,             /* tp_members */
