@@ -16,10 +16,10 @@
 #define MAX_FDS 1024 * 8
 #define ACCEPT_TIMEOUT_SECS 1
 #define SHORT_TIMEOUT_SECS 2
-#define WRITE_TIMEOUT_SECS 5
+#define WRITE_TIMEOUT_SECS 15
 #define READ_LONG_TIMEOUT_SECS 5
 
-#define BACKLOG 1024
+#define BACKLOG 1024 * 8
 #define MAX_BUFSIZE 1024 * 8
 #define INPUT_BUF_SIZE 1024 * 8
 
@@ -331,9 +331,15 @@ r_callback(picoev_loop* loop, int fd, int events, void* cb_arg)
         }
         r = read(cli->fd, buf, sizeof(buf));
         switch (r) {
+            /*
+            read 0 occured overload
             case 0: 
-                finish = 1;
-                break;
+                cli->keep_alive = 0;
+                cli->status_code = 503;
+                send_error_page(cli);
+                close_conn(cli, loop);
+                return;
+            */
             case -1: /* error */
                 if (errno == EAGAIN || errno == EWOULDBLOCK) { /* try again later */
                     break;
@@ -342,6 +348,7 @@ r_callback(picoev_loop* loop, int fd, int events, void* cb_arg)
                     write_error_log(__FILE__, __LINE__); 
                     cli->keep_alive = 0;
                     cli->status_code = 500;
+                    send_error_page(cli);
                     close_conn(cli, loop);
                     return;
                 }
